pitchtools.transpose_pitch_class_number_to_pitch_number_neighbor
================================================================

.. autofunction:: abjad.tools.pitchtools.transpose_pitch_class_number_to_pitch_number_neighbor.transpose_pitch_class_number_to_pitch_number_neighbor
